@@ -2,7 +2,7 @@ package Chicken::Ipsum;
 use strict;
 use warnings;
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -152,7 +152,7 @@ sub _get_sentence {
 
 =head1 AUTHOR
 
-Dan Church (DCHURCH on CPAN)
+Dan Church (h3xx<attyzatzat>gmx<dottydot>com)
 
 =head1 SEE ALSO
 
@@ -162,7 +162,7 @@ L<https://isotropic.org/papers/chicken.pdf>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2023 Dan Church (h3xx<attyzatzat>gmx<dottydot>com).
+Copyright (C) 2023 Dan Church.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
